# The root file to load the entire gphys package except GGraph.

require 'numru/gphys/gphys'
require "numru/gphys/gphys_io"
require 'numru/gphys/gphys_fft'
require 'numru/gphys/ep_flux'
require 'numru/gdir'
begin
  require 'numru/gphys_ext'  # extension library, which is yet to be completed
rescue LoadError
end
